@@ -166,4 +166,4 @@ class LambdaHandler:
         self.track(tx, context.payload().get("data", {}))
 
     def enqueue(self, tx, action, payload={}):
-        enqueue(tx, action, payload, self.session["email_address"])
+        return enqueue(tx, action, payload, self.session["email_address"])
