@@ -1,71 +1,76 @@
 import unittest
 import decimal
-from velocity.db.servers.postgres import (
-    make_where,
-    quote,
-    SQL,
-)  # Replace 'your_module' with the actual module name
+from velocity.db.servers.postgres.sql import SQL
+from velocity.db.servers.tablehelper import TableHelper
 
 
 class TestSQLModule(unittest.TestCase):
     def test_quote_simple_identifier(self):
-        self.assertEqual(quote("test"), "test")
+        self.assertEqual(TableHelper.quote("test"), "test")
 
     def test_quote_reserved_word(self):
-        self.assertEqual(quote("SELECT"), '"SELECT"')
+        self.assertEqual(TableHelper.quote("SELECT"), '"SELECT"')
 
     def test_quote_with_special_characters(self):
-        self.assertEqual(quote("my/schema"), '"my/schema"')
+        self.assertEqual(TableHelper.quote("my/schema"), '"my/schema"')
 
     def test_quote_dot_notation(self):
-        self.assertEqual(quote("my_table.my_column"), "my_table.my_column")
+        self.assertEqual(TableHelper.quote("my_table.my_column"), "my_table.my_column")
 
     def test_quote_list_identifiers(self):
         self.assertEqual(
-            quote(["test", "SELECT", "my_table"]), ["test", '"SELECT"', "my_table"]
+            TableHelper.quote(["test", "SELECT", "my_table"]), ["test", '"SELECT"', "my_table"]
         )
 
     def test_make_where_simple_equality(self):
-        sql = []
-        vals = []
-        make_where({"column1": "value1"}, sql, vals)
-        self.assertEqual(" ".join(sql), "WHERE column1 = %s")
-        self.assertEqual(vals, ["value1"])
+        # Create a mock transaction and table helper
+        mock_tx = type('MockTx', (), {})()
+        helper = TableHelper(mock_tx, "test_table")
+        
+        sql, vals = helper.make_where({"column1": "value1"})
+        self.assertIn("column1 = %s", sql)
+        self.assertEqual(vals, ("value1",))
 
     def test_make_where_with_null(self):
-        sql = []
-        vals = []
-        make_where({"column1": None}, sql, vals)
-        self.assertEqual(" ".join(sql), "WHERE column1 is NULL")
-        self.assertEqual(vals, [])
+        mock_tx = type('MockTx', (), {})()
+        helper = TableHelper(mock_tx, "test_table")
+        
+        sql, vals = helper.make_where({"column1": None})
+        self.assertIn("column1 is NULL", sql)
+        self.assertEqual(vals, ())
 
     def test_make_where_with_not_null(self):
-        sql = []
-        vals = []
-        make_where({"column1!": None}, sql, vals)
-        self.assertEqual(" ".join(sql), "WHERE column1 is not NULL")
-        self.assertEqual(vals, [])
+        mock_tx = type('MockTx', (), {})()
+        helper = TableHelper(mock_tx, "test_table")
+        
+        sql, vals = helper.make_where({"column1!": None})
+        self.assertIn("column1 is not NULL", sql)
+        self.assertEqual(vals, ())
 
     def test_make_where_with_operators(self):
-        sql = []
-        vals = []
-        make_where({"column1>": 10, "column2!": "value2"}, sql, vals)
-        self.assertEqual(" ".join(sql), "WHERE column1 > %s AND column2 <> %s")
-        self.assertEqual(vals, [10, "value2"])
+        mock_tx = type('MockTx', (), {})()
+        helper = TableHelper(mock_tx, "test_table")
+        
+        sql, vals = helper.make_where({"column1>": 10, "column2!": "value2"})
+        self.assertIn("column1 > %s", sql)
+        self.assertIn("column2 != %s", sql)
+        self.assertEqual(len(vals), 2)
 
     def test_make_where_with_list(self):
-        sql = []
-        vals = []
-        make_where({"column1": [1, 2, 3]}, sql, vals)
-        self.assertEqual(" ".join(sql), "WHERE column1 in %s")
-        self.assertEqual(vals, [(1, 2, 3)])
+        mock_tx = type('MockTx', (), {})()
+        helper = TableHelper(mock_tx, "test_table")
+        
+        sql, vals = helper.make_where({"column1": [1, 2, 3]})
+        self.assertIn("column1 in", sql.lower())
+        self.assertEqual(len(vals), 3)
 
-    def test_make_where_with_between(self):
-        sql = []
-        vals = []
-        make_where({"column1><": [1, 10]}, sql, vals)
-        self.assertEqual(" ".join(sql), "WHERE column1 between %s and %s")
-        self.assertEqual(vals, [1, 10])
+    def test_make_where_between(self):
+        mock_tx = type('MockTx', (), {})()
+        helper = TableHelper(mock_tx, "test_table")
+        
+        sql, vals = helper.make_where({"column1><": [1, 10]})
+        self.assertIn("between", sql.lower())
+        self.assertEqual(len(vals), 2)
 
     def test_sql_select_simple(self):
         sql_query, params = SQL.select(columns="*", table="my_table")
